OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "khôi phục",
    "Deleted files" : "File đã bị xóa",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Các tệp và thư mục đã xóa trong thùng rác (có thể hết hạn trong quá trình xuất nếu bạn sắp hết dung lượng lưu trữ)",
    "Restore" : "Khôi phục",
    "Cancel" : "Hủy bỏ",
    "Deleted" : "Đã xóa",
    "A long time ago" : "Một khoảng thời gian trước",
    "Unknown" : "Không xác định",
    "All files" : "Tất cả tệp tin",
    "You" : "You",
    "List of files that have been deleted." : "Danh sách các tập tin đã bị xóa.",
    "No deleted files" : "Không có tập tin bị xóa",
    "Files and folders you have deleted will show up here" : "Các tập tin và thư mục bạn đã xóa sẽ hiển thị ở đây",
    "Deletion cancelled" : "Thao tác xóa bị hủy"
},
"nplurals=1; plural=0;");
